Index of Terms
Affirmative Express Consent#
- A standard process where Users must clearly understand what they are agreeing to and what they get in exchange.
Auth Framework#
- The core capabilities that support integration with common Authentication and Authorization standards.
Category#
- A collection of Field names that is used in Configuration to define valid data for a given purpose.
Change Data Capture#
- A data format, available via a streaming endpoint, that provides the complete revisioned Context Graph. This format can be used to maintain a view of the full context set over time in a graph database, to manage data across datastores, to discover how data has been connected or kept isolated, to view all changes to policy over time etc.
Child#
- A User who is associated with a Guardian as possibly being below the threshold age. The relationship may persist past the point where a User is older than the threshold age, at which point policy will not support Guardian access but it my still be useful to track the relationship for audit purposes.
Configuration#
- A complete definition for what constitutes correct data use across the Platform, Contracts, and Consents.
Consent#
- The process by which a User agrees to sharing data for some known reason.
Consented Exchange#
- Sharing data under specific Consent Terms.
Context#
- Details that may affect a decision like the age of a user, the contract covering a record, or the location where a given record is being accessed.
Context Graph#
- The full, versioned graph capuring the context of data and users, and connecting it to policy and data model.
Context Store#
- The storage service where the computed Context Graph is kept.
Contractual Exchange#
- Sharing data under specific Contract Terms.
Decision#
- A response to a request to assert a given Purpose for a given Record, including a reason for the decision and possibly providing a redacted version of the Record.
Decision Trace#
- A data format, available via a streaming endpoint, that captures each Decision and the input to that decision, explaining why the decision was made.
Descision#
- For each request for data, a detailed response from the engine explaining why the request was allowed or denied, and what context was resolved that went into the decision process.
Description#
- A summary field and full description associated with a Configuration component.
Export#
- Providing access to a backing datastore by acting as an intermediary on the wire.
Field#
- A specific named component of a Category.
First Party#
- A User who has accepted Platform Terms.
Guardian#
- A user who may or may not be a First Party, but who is associated with a Child and is given specific rights as long as the Child is below some stated age.
Ledger#
- A distributed blockchain, stored at each peer, that maintains core knowledge like the peer's identity, each Configuration change, and each Mapping change.
Mapping#
- Multiple definitions from the Categories and Fields of Configuration to the schema and structure of a given datastore or document format.
Opt-In#
- A Platform Use Purpose that may not be asserted for a given User's data unless that User explicitly agrees to the use.
Override#
- A condition, like a User's age or location, that affects Platform Use, Platform Sharing, or User Access.
Personal Terms#
- The set of Platform Terms that apply to a given User based on their Context.
Platform#
- The environment that has defined Configuration for data use and sharing.
Platform Terms#
- The Terms that cover how a First Party's data may be used.
Platform Sharing#
- A request to access data on balf of some stated Third Party for a stated Purpose.
Platform Use#
- A request to access data on balf of the Platform for a stated Purpose.
Purpose#
- A stated rationale for why access is being requested.
Query Subject#
- The party that is associated with a query, like the Third Party for Platform Sharing, the specific Terms for Consented Sharing, or the requesting User for User Access.
Record#
- A single record-version of data provided for a Decision, like a row in a SQL Database, a line in CSV file, or a Key-Value pair in a call to an API.
Redaction#
- A process to remove from a Record any Field values that are not included in the allowed Categories for a Decision.
Resource Subject#
- The User associated with the Record being requested.
Service Provider#
- A Third-Party that receives data as a trusted steward of that data and agrees not to use that data in any way.
Terms#
- Identifiable contract, consent, or platform definitions that define or restrict data use or sharing.
Third Party#
- Third Party has two meanings:
-
- An external party, as part of a Platform Sharing Purpose, that receives data
- A User who has not accepted Patform Terms but has data on the platform, typically via a B2B exchange
-
In case 2, the user is not active on the platform and so only Contractual Terms apply to the use and sharing of their data.
User#
- An individual known to the Platform, either because the Platform has their data or because the User can interact with the Platoform on behalf of some other User's data.
User Access#
- A request to access data on behalf of a User.